@@ -1,33 +1,33 @@
 .bc.main <- 
 function(x, y, by, 
-         fill, col.color, col.bg, col.box, col.trans, theme,
-         horiz, addtop, gap, prop,
-         xlab, ylab, main, lab.cex,
-         value.labels, label.max,
-         axis.cex, cex.names, rotate.x, rotate.y, offset, beside,
+         fill, col.color, col.trans, theme,
+         horiz, addtop, gap, prop, scale.y,
+         xlab, ylab, main,
+         value.labels, label.max, beside,
+         rotate.x, offset, break.x, sort.x,
+         values, values.color, values.cex, values.digits, values.pos,
+         xlab.adj, ylab.adj, bm.adj, lm.adj, tm.adj, rm.adj,
          legend.title, legend.loc, legend.labels, legend.horiz,
-         add, x1, x2, y1, y2, quiet, ...) {
+         add, x1, x2, y1, y2, out.size, quiet, ...) {
 
   # if x is integer, not labeled correctly
   if (length(unique(x)) != length(x)) if (!is.factor(x)) x <- factor(x)
-
-  # scale for regular R or RStudio
-  #adj <- .RSadj(radius=NULL, axis.cex, cex.names, lab.cex)
-  #size.axis <- adj$size.axis
-  #size.lab <- adj$size.lab
-  #size.txt <- adj$size.txt
-
+  
   if ( (is.table(x) || is.matrix(x)) && is.null(legend.title) ) { 
     cat("\n"); stop(call.=FALSE, "\n","------\n",
     "Need to specify a value for:  legend.title\n\n")
   }
 
-  # get values for ... parameter values
-  #stuff <- .getdots(...)
-  #col.main <- stuff$col.main
-  #col.lab <- stuff$col.lab
-  #col.sub <- stuff$col.sub
-  #cex.main <- stuff$cex.main
+  # --------------------------------------
+  # axis values, axis labels, legend setup
+
+  # get axis.x.cex, axis.y.cex
+  axis.x.cex <- ifelse(is.null(getOption("axis.x.cex")), 
+    getOption("axis.cex"), getOption("axis.x.cex"))
+  adj <- .RSadj(axis.cex=axis.x.cex); axis.x.cex <- adj$axis.cex
+  axis.y.cex <- ifelse(is.null(getOption("axis.y.cex")), 
+    getOption("axis.cex"), getOption("axis.y.cex"))
+  adj <- .RSadj(axis.cex=axis.y.cex); axis.y.cex <- adj$axis.cex
 
   # get lab.x.cex  lab.y.cex
   lab.cex <- getOption("lab.cex")
@@ -39,16 +39,14 @@ function(x, y, by,
   adj <- .RSadj(lab.cex=lab.y.cex); lab.y.cex <- adj$lab.cex
 
   gl <- .getlabels(xlab, ylab, main, by.nm=TRUE, lab.x.cex=lab.x.cex, 
-                   lab.y.cex=lab.y.cex)
-  x.name <- gl$xn; x.lab <- gl$xb; x.lbl <- gl$xl
-  y.lbl <- gl$yl
-  by.name <- y.lbl
+                   lab.y.cex=lab.y.cex, flip=horiz)
+  x.name <- gl$xn;  x.lbl <- gl$xl;  y.lbl <- gl$yl
+  x.lab <- ifelse (horiz, gl$yb, gl$xb)
   main.lab <- gl$mb
-  lab.x.cex <- gl$lab.x.cex
-  lab.y.cex <- gl$lab.y.cex
+  by.name <- y.lbl
   if (!is.null(by)) by.name <- getOption("byname")
 
-  ylab.keep <- ifelse(is.null(ylab), FALSE, TRUE)
+  ylab.keep <- ifelse (is.null(ylab), FALSE, TRUE)
 
   if (ylab.keep) {
       y.lab <- ylab
@@ -91,15 +89,6 @@ function(x, y, by,
     options(byname = legend.title)
   }
 
-  # if a table, convert to a matrix
-  #if (is.table(x)) {
-    #xr.nm <- rownames(x)
-    #xc.nm <- colnames(x)  # as.numeric makes equivalent to matrix input
-    #x <- matrix(as.numeric(x), nrow=nrow(x), ncol=ncol(x))
-    #rownames(x) <- xr.nm
-    #colnames(x) <- xc.nm
-  #}
-
   # get legend title, l.lab
   if (!is.null(legend.title))
     l.lab <- legend.title 
@@ -110,6 +99,14 @@ function(x, y, by,
   # title
   main.lbl <- ifelse (!is.null(main), main, "")
 
+
+  # --------------------------
+  # get missing, data entered? 
+
+  x.miss <- sum(is.na(x))
+  by.miss <- NULL
+  by.miss <- if (!is.null(by)) sum(is.na(by))
+
   # entered counts typically integers as entered but stored as type double
   # if names(x) or rownames(x) is null, likely data from sample and c functions
   # y is getting data values directly from a data frame with counts entered
@@ -118,10 +115,16 @@ function(x, y, by,
   if (is.matrix(x) && !is.null(rownames(x))) entered.pre <- TRUE
   entered <- ifelse (!is.integer(x) && is.double(x) && entered.pre, TRUE, FALSE)
 
+  if (is.null(by) && beside && !entered) { 
+    cat("\n"); stop(call.=FALSE, "\n","------\n",
+    "beside=TRUE  is not valid for analysis of only one variable.\n\n")
+  }
 
-  # -------------------------------
-  # do not do counts, y is provided
 
+  # -------------------------------------------
+  # get Y variable, either directly or tabulate
+
+  # do not tabulate counts, y is provided
   if (!is.null(y)) {
     entered <- TRUE
 	
@@ -131,13 +134,10 @@ function(x, y, by,
         cat("\n"); stop(call.=FALSE, "\n","------\n",
           "y-values, those from the 2nd unlabeled variable, ", yn, ",",
           " must be\n", " numeric\n\n",
-          "A by variable is categorical, with a small number of potentially\n",
-          "  non-numeric values\n",
+          "A  by  variable is categorical, with a small number of values\n",
           "It appears that ", yn, " is a by variable\n",
-          "As of lessR 3.5.6, explicitly indicate the by variable if it\n",
-          "  second in the list for the function call\n\n",
-          "To specify a by variable as the 2nd variable in the function call,\n",
-          "  explicitly precede its name with:  by=", "\n\n")
+          "As of lessR 3.5.6 to specify a  by  variable in the function call\n",
+          "  precede its name with:  by=", "\n\n")
       } 
 
       if (anyDuplicated(names(x)) > 0) {
@@ -148,22 +148,23 @@ function(x, y, by,
       if (length(y) > 20) {
         warning(call.=FALSE, "There are more than 20 categories to plot\n\n",
             "Perhaps you mean for the 2nd variable, ", yn, ", to be a",
-            " by variable\n",
-            "  even though it is numeric\n\n",
+            "by  variable even though it is numeric\n\n",
             "A by variable only has a small number of values\n\n",
-            "To specify a by variable as the 2nd variable in the",
-            " function call,\n",
-            "  explicitly precede its name with:  by=", "\n\n")
+            "Explicitly precede the variable's name with:  by=", "\n\n")
      }
 
       x.temp <- x
       x <- y
       names(x) <- x.temp
       x <- as.table(x)
-      if (prop) x <- x/sum(x)
+      if (prop) {
+        x.count <- x  # save table of counts for possible bar display
+        x <- x/sum(x)
+      }
     }
 
     else {  # a by variable
+      x.temp <- x
       do.row <- ifelse (x[1] == x[2], FALSE, TRUE)  # x is outer loop
       m <- matrix(y, nrow=length(levels(by)), byrow=do.row)
       colnames(m) <- unique(x) 
@@ -171,18 +172,26 @@ function(x, y, by,
       m <- as.table(m, dnn=c(by.name, x.name))
       names(dimnames(m)) <- c(by.name, x.name) 
       x <- m
-      if (prop) x <- prop.table(x, 2)
+      if (prop) {
+        x.count <- x  # save table of counts for possible bar display
+        x <- prop.table(x, 2)
+      }
     }
   }  # end !is.null(y)
 
-  
-  # save ordered status before converting x to a table
-  order.x <- ifelse (is.ordered(x) && is.null(by), TRUE, FALSE)
-  order.y <- ifelse (is.ordered(by), TRUE, FALSE)
 
   # tabulate for counts
-  if (!entered) {  # x.temp allows frequencies to be restored for text output
-    if (!is.null(by)) {
+
+  if (!entered) {  
+    if (is.null(by)) {
+      x.temp <- x  # save counts, to be restored for text output
+      x <- table(x, dnn=NULL)
+      if (prop) {
+        x.count <- x  # save table of counts for possible bar display
+        x <- x/sum(x)
+      }
+    }
+    else {  # a by variable
       if (length(x) == length(by))
         x.temp <- table(by,x, dnn=c(by.name, x.name))
       else {
@@ -191,20 +200,36 @@ function(x, y, by,
         "Size of ", x.name, ": ", length(x), "\n", 
         "Size of ", by.name, ": ", length(by), "\n\n", sep="")
       }
-      x <- table(by,x, dnn=c(by.name, x.name))
-      if (prop) x <- prop.table(x, 2)
+      x <- table(by, x, dnn=c(by.name, x.name))
+      if (prop) {
+        x.count <- x  # save table of counts for possible bar display
+        x <-prop.table(x, 2)
+      }
     }
-    else {  # one variable 
-      x.temp <- x  # save counts
-      x <- table(x, dnn=NULL)
-      if (prop) x <- x/sum(x)
+  }  # end !entered so tabulate
+
+  if (prop) {
+    if (any(is.nan(x))) {
+      cat("\n"); stop(call.=FALSE, "\n","------\n",
+        "Some cells (frequencies) are zero\n",
+        "Division to calculate proportions not possible\n",
+        "Run analysis without  prop  to identify the 0 cells\n\n")
     }
-  }  # end !entered
+  }
 
+  # ------------
+  # sort options
 
-  if (is.null(by) && beside && !entered) { 
-    cat("\n"); stop(call.=FALSE, "\n","------\n",
-    "beside=TRUE  is not valid for analysis of only one variable.\n\n")
+  if (sort.x != "off") {
+    srt.dwn <- ifelse (sort.x == "down", TRUE, FALSE)
+    if (is.null(by)) {
+      x <- x[order(x, decreasing=srt.dwn)]
+    }
+    else {
+      x.df <- as.data.frame.matrix(x, nrow=2)
+      x.df <- x.df[order(apply(x.df, 2, sum), decreasing=srt.dwn)]
+      x <- as.table(as.matrix(x.df))
+    }
   }
 
 
@@ -213,12 +238,12 @@ function(x, y, by,
 
   # if use getColors to generate a range of colors
   if (is.null(by) && !is.matrix(x))
-    n.clr <- length(x)
+    n.cat <- length(x)  
   else
-    n.clr <- nrow(x)
-  if (!is.null(by)) n.clr <- nrow(x)
+    n.cat <- nrow(x)
+  if (!is.null(by)) n.cat <- nrow(x)  # num cat for by variable
   # see if apply a pre-defined color range
-  if (length(fill) == 1) fill <- .color.range(fill, n.clr)
+  if (length(fill) == 1) fill <- .color.range(fill, n.cat)  # range
 
   # get n.colors (does not indicate fill multiple colors)
   if (is.null(by) && !is.matrix(x))
@@ -243,7 +268,8 @@ function(x, y, by,
 
   # ----------------------------------------------------------------------------
   # preliminaries
- 
+
+  if (values.pos == "out") addtop <- addtop + .02  # kludge
   max.y <- ifelse (is.matrix(x) && !beside, max(colSums(x)), max(x))
   max.y <- max.y + (addtop * max.y)
 
@@ -265,30 +291,24 @@ function(x, y, by,
       gap <- 0.2
   }
 
-  # get max label size
+  # get the names
   the.names <- integer(length=0)
   if (length(dim(x)) == 0)
     the.names <- names(x)
-  else
-    if (is.null(by))
+  else {
+    if (is.null(by))  # ifelse does not work
       the.names <- rownames(x)
     else
       the.names <- colnames(x)
-
-  max.nm <- 0
-  for (i in (1:length(the.names))) {
-    li <- ifelse (!is.na(the.names[i]), nchar(the.names[i]), 0)
-    if (li > max.nm) max.nm <- li
   }
-  
+
   # labels horiz or vertical
-  las.value <- ifelse (horiz  && max.nm > 5, 0, 1)
+  las.value <- ifelse (horiz  && max(nchar(the.names)) > 5, 0, 1)
 
   
-  # ----------------------------------------------------------------------------
-  # set up plot area
-
+  # ------------
   # value labels
+
   if (!is.null(value.labels)) {
     val.lab <- value.labels
   }
@@ -301,58 +321,83 @@ function(x, y, by,
     if (!is.null(names(y))) val.lab <- names(y)
   }
 
-  for (i in 1:length(val.lab))  # for each value label, partition into lines
-    val.lab[i] <- .makelines(val.lab[i], mx.ch=11)
-  if (!is.null(val.lab)) val.lab <- .abbrev(val.lab, label.max)
- 
-  if(is.null(y)) if (horiz) {  # switch
-    temp <- x.lab
-    x.lab <- y.lab
-    y.lab <- temp  # FIX: label size processed as x.lab, maybe too large
+  # for each value label, partition into mx.x.val.ln lines if (break.x)
+  mx.x.val.ln <- 1
+  ln.val <- integer(length=length(val.lab))
+  if (break.x) {
+    stuff <- .get.val.ln(val.lab, x.name)
+  }
+  val.lab <- stuff$val.lab 
+  mx.x.val.ln <- stuff$mx.val.ln
+
+  mx.y.val.ln <- 1
+
+  if (is.null(y)) if (horiz) {  # switch
+    temp <- x.lab;  x.lab <- y.lab;  y.lab <- temp
+    temp <- mx.x.val.ln;  mx.x.val.ln <- mx.y.val.ln;  mx.y.val.ln <- temp
   }
 
-  ly <- length(y.lab)
-  if (ly > 1) {  # not perfect, but some line break better than none
-    if (nchar(y.lab[ly]) > 38) {
-      brk <- nchar(y.lab[ly]) %/% 2  # break label down the middle
-      while (substr(y.lab[ly],brk,brk) != " ") brk <- brk-1  # break at a word
-      line1 <- substr(y.lab[ly], 1, brk)
-      line2 <- substr(y.lab[ly], brk+1, nchar(y.lab[ly]))
-      y.lab[ly] <- paste(line1, "\n",  line2)
-    }
+  # set max.val.width to get max width of y-axis labels for lm adjustment
+  lblval.y <- character(length=0)
+  if (is.null(scale.y)) {
+    prety <- max(pretty(c(min.y, max.y)))
+    mx.num <-  ifelse (!prop, as.character(prety), .fmt(prety, 2))
+    max.y.width <- max(strwidth(mx.num, cex=axis.y.cex, units="inches"))
+
+  }
+  else {  # need scale to be defined to get y.coords, not done till later
+    ax.num <- ifelse(horiz, 1, 2)  # location of numerical axis
+    y.coords <- axTicks(ax.num, axp=scale.y)
+    nd <- 0
+    for (i in 1:length(y.coords))
+      if (.num.dec(y.coords[i]) > nd) nd <- .num.dec(y.coords[i])
+    if (nd > 2) nd <- 2  # only allow a few decimal digits
+    for (i in 1: length(y.coords))
+      lblval.y[i] <- as.character(.fmt(y.coords[i], nd))
+    j <- which(nchar(lblval.y) == max(nchar(lblval.y)))[1]
+    max.y.width <- max(strwidth(lblval.y[j], cex=axis.y.cex, units="inches"))
   }
 
-  if (!horiz)
-    max.width <- strwidth(as.character(max(pretty(c(min.y, max.y)))),
-                          units="inches")
-  else {
-    val.split <- unlist(strsplit(val.lab, "\n"))
-    # strange strwidth bug, 1st time works, 2nd time too large by 0.5
-    # refresh source code, works again until 2nd time
-    #max.width <- strwidth(max(val.split), units="inches") 
-    max.width <- nchar(max(val.split)) / 16
- }
+  max.x.width <- NULL
+  if (horiz  ||  rotate.x == 90) {  # "y"-axis is categorical (i.e., x-axis)
+    val.split <- unlist(strsplit(val.lab, "\n"))  # break into separate words
+    if (horiz)
+      max.y.width <- max(strwidth(val.split, cex=axis.x.cex, units="inches"))
+    else
+      max.x.width <- max(strwidth(val.split, cex=axis.x.cex, units="inches"))
+  }
 
-  margs <- .marg(max.width, y.lab, x.lab, main.lab, x.val=val.lab, prop,
-                 rotate.x)
+  
+  # ----------------
+  # set up plot area
+
+  margs <- .marg(max.y.width, y.lab, x.lab, main.lab,
+                rotate.x, mx.x.val.ln, mx.y.val.ln,
+                lab.x.cex=lab.x.cex, lab.y.cex=lab.y.cex, max.x.width)
   lm <- margs$lm
   tm <- margs$tm
   rm <- margs$rm
   bm <- margs$bm
- 
-  if (horiz) {
-    bm <- bm + .10  # kludge, for horiz, long labels overrun plot area
-    #lm <- lm + .06
-    if (las.value == 1) lm <- lm + .12
-  }
+  n.lab.x.ln <- margs$n.lab.x.ln
+  n.lab.y.ln <- margs$n.lab.y.ln
+
+  if (horiz)
+    rm <- rm + 0.1  # sometimes the max axis value goes off the plot
+  else 
+    if (offset > 0.5) bm <- bm + (-0.05 + 0.2 * offset)  # offset kludge
+
   if (legend.loc == "right.margin"  &&  (!is.null(by) || is.matrix(x)))
     rm <- rm + .82
- 
+
+  # user manual adjustment
+  bm <- bm + bm.adj
+  lm <- lm + lm.adj
+  tm <- tm + tm.adj
+  rm <- rm + rm.adj
+
   orig.params <- par(no.readonly=TRUE)
   on.exit(par(orig.params))
 
-  par(bg=getOption("window.fill"))
-  par(mai=c(bm, lm, tm, rm))
 
   # rescale to control bar width for small number of bars
   # set rescale
@@ -367,9 +412,12 @@ function(x, y, by,
   if (rescale == 2) width.bars <- .28
   if (rescale > 0) gap <- 0.246 + (0.687 * width.bars)
 
-  # barplot run here only to establish usr coordinates
+  par(bg=getOption("window.fill"))
+  par(mai=c(bm, lm, tm, rm))
+
+  # barplot run here only to establish usr coordinates, axTick values
   #  otherwise usr is just 0,1 for both axes
-  # the barplot itself is not retained, but overwritten
+  # the barplot itself is not retained
   if (rescale == 0) {
     if (!horiz)
       barplot(x, col="transparent", ylim=c(min.y,max.y), axisnames=FALSE,
@@ -389,111 +437,174 @@ function(x, y, by,
         ylim=c(0,1), axes=FALSE, ...)
   }
 
+  ax.num <- ifelse(horiz, 1, 2)  # location of numerical axis
+  y.coords <- axTicks(ax.num, axp=scale.y)
 
-  # ----------------------------------------------------------------------------
-  # bar plot, grid lines
+
+  ## ----
+  ## PLOT
 
   usr <- par("usr")
-  
+
+  # panel fill
+  col.bg <- getOption("panel.fill")
   rect(usr[1], usr[3], usr[2], usr[4], col=col.bg, border="transparent")
 
-  grid.x.color <- ifelse(is.null(getOption("grid.x.color")), 
-    getOption("grid.color"), getOption("grid.x.color"))
-  grid.y.color <- ifelse(is.null(getOption("grid.y.color")), 
-    getOption("grid.color"), getOption("grid.y.color"))
- 
-  grid.x.lwd <- ifelse(is.null(getOption("grid.x.lwd")), 
-    getOption("grid.lwd"), getOption("grid.x.lwd"))
-  grid.y.lwd <- ifelse(is.null(getOption("grid.y.lwd")), 
-    getOption("grid.lwd"), getOption("grid.y.lwd"))
-
-  grid.x.lty <- ifelse(is.null(getOption("grid.x.lty")), 
-    getOption("grid.lty"), getOption("grid.x.lty"))
-  grid.y.lty <- ifelse(is.null(getOption("grid.y.lty")), 
-    getOption("grid.lty"), getOption("grid.y.lty"))
- 
-  ax.num <- ifelse(horiz, 1, 2)  # location of numerical axis
-  vy <- pretty(min.y:max.y)
-  if (!horiz)
-    abline(h=axTicks(ax.num), col=grid.y.color, lwd=grid.y.lwd, lty=grid.y.lty)
-  else
-    abline(v=axTicks(ax.num), col=grid.x.color, lwd=grid.x.lwd, lty=grid.x.lty)  
+  # grid lines for y-axis only
+  .grid(ifelse(horiz, "v", "h"), y.coords) 
 
   # box around plot
-  rect(usr[1], usr[3], usr[2], usr[4], col="transparent", border=col.box,
-    lwd=getOption("panel.lwd"), lty=getOption("panel.lty"))
+  rect(usr[1], usr[3], usr[2], usr[4], col="transparent",
+       border=getOption("panel.color"),
+       lwd=getOption("panel.lwd"), lty=getOption("panel.lty"))
 
-  ## PLOT
+  # the bars
   if (rescale == 0)
-    coords <- barplot(x, add=TRUE, col=fill, beside=beside, horiz=horiz,
+    x.coords <- barplot(x, add=TRUE, col=fill, beside=beside, horiz=horiz,
           axes=FALSE, ann=FALSE, border=col.color, las=las.value, 
           space=gap, axisnames=FALSE, ...)
   else
-    coords <- barplot(x, add=TRUE, col=fill, beside=beside, horiz=horiz,
+    x.coords <- barplot(x, add=TRUE, col=fill, beside=beside, horiz=horiz,
           axes=FALSE, ann=FALSE, border=col.color, las=las.value, 
           space=gap, width=width.bars, xlim=c(0,1), axisnames=FALSE, ...)
 
-  # axes
+  # text labels on or above the bars
+  if (values != "off") {
+
+    if (!prop) {
+      if (values == "input")
+        x.txt <- as.character(x)
+      else if (values == "%")
+        x.txt <- paste(.fmt(x/sum(x) * 100, values.digits), "%", sep="")
+      else if (values == "prop")
+        x.txt <- .fmt(x/sum(x), values.digits)
+    }
+    else {  # prop
+      if (values == "input")
+        x.txt <- as.character(x.count)
+      else if (values == "%")
+        x.txt <- paste(.fmt(x * 100, values.digits), "%", sep="")
+      else if (values == "prop")
+        x.txt <- .fmt(x, values.digits)
+    }
+
+    # as.numeric & as.character convert table to vector: re-convert
+    if (!is.null(by)) x.txt <- matrix(x.txt, nrow=nrow(x))
+
+    if (!horiz) {
+      if (is.null(by)) {
+        if (values.pos == "out") {
+           usr.y.in <- diff(grconvertY(0:1, 'inches', 'user'))
+           ycrd <- x + .1 * usr.y.in 
+        } 
+        else
+          ycrd <- x/2
+        text(x.coords, ycrd, labels=x.txt, col=values.color, cex=values.cex)
+      }  # no by
+      else {
+        for (i in 1:ncol(x)) {
+          mid.x <- cumsum(x[,i]) - (x[,i] / 2)
+          text(x.coords[i], mid.x, labels=x.txt[,i],
+             col=values.color, cex=values.cex) 
+        }
+      }
+    }
+    else {  # horiz
+      if (is.null(by)) {
+        if (values.pos == "out") {
+           usr.x.in <- diff(grconvertX(0:1, 'inches', 'user')) 
+           ycrd <- x + .17 * usr.x.in 
+        } 
+        else
+          ycrd <- x/2
+        text(ycrd, x.coords, labels=x.txt, col=values.color, cex=values.cex)
+      }  # no by
+      else {
+        for (i in 1:ncol(x)) {
+          mid.x <- cumsum(x[,i]) - (x[,i] / 2)
+          text(mid.x, x.coords[i], labels=x.txt[,i],
+             col=values.color, cex=values.cex) 
+        }
+      }  # end !horiz
+    }
+  }  # end values
+
+  # y-axis
   if (!horiz) las.value <- 1
   axis.y.color <- ifelse(is.null(getOption("axis.y.color")), 
     getOption("axis.color"), getOption("axis.y.color"))
-  axis.y.cex <- ifelse(is.null(getOption("axis.y.cex")), 
-    getOption("axis.cex"), getOption("axis.y.cex"))
-  adj <- .RSadj(axis.cex=axis.y.cex); axis.y.cex <- adj$axis.cex
-  axis(ax.num, col=axis.y.color,
-       col.axis=axis.y.color, cex.axis=axis.y.cex,
-       las=las.value, ...) 
+  axis.y.text.color <- ifelse(is.null(getOption("axis.y.text.color")), 
+    getOption("axis.text.color"), getOption("axis.y.text.color"))
+  adj1 <- ifelse (!horiz, 0.5, -1.0)
+  if (is.null(scale.y))  # if scale.y defined, can evaluate earlier
+    lblval.y <- as.character(y.coords)
+  axis(ax.num, col=axis.y.color,   # maybe split off the text like with x axis?
+       col.axis=axis.y.text.color, cex.axis=axis.y.cex, las=las.value,
+       tck=-.03, padj=adj1,  at=y.coords, labels=lblval.y, ...) 
+       #tck=-.03, padj=adj1,  at=axTicks(ax.num, axp=scale.y), ...) 
   
-  if (beside) coords <- apply(coords, 2, mean)  # one label per group
-  if (!horiz) {
-    ax.value <- 1;  xx <- coords;  yy <- par("usr")[3]
-  }
-  else {
-    ax.value <- 2;  xx <- par("usr")[3];  yy <- coords
-  }
-  if (horiz) xx <- -0.032  # otherwise usr3 is a + value
+  # x-axis is the category value axis
   axis.x.color <- ifelse(is.null(getOption("axis.x.color")), 
     getOption("axis.color"), getOption("axis.x.color"))
-  axis.x.cex <- ifelse(is.null(getOption("axis.x.cex")), 
-    getOption("axis.cex"), getOption("axis.x.cex"))
-  adj <- .RSadj(axis.cex=axis.x.cex); axis.x.cex <- adj$axis.cex
-  axis(ax.value, at=coords, labels=FALSE, tck=-.01,
-       col=axis.x.color, cex.axis=axis.x.cex, ...)
-  text(x=xx, y=yy, labels=val.lab,
-       pos=ax.value, xpd=TRUE, cex=axis.x.cex,
-       col=getOption("axis.text.color"), srt=rotate.x, offset=offset, ...)
-    
+  axis.x.text.color <- ifelse(is.null(getOption("axis.x.text.color")), 
+    getOption("axis.text.color"), getOption("axis.x.text.color"))
+
+
+  if (beside) x.coords <- apply(x.coords, 2, mean)  # one label per group
+  if (!horiz) {
+    usr.y.in <- diff(grconvertY(0:1, 'inches', 'user'))  # y user x.coords inch
+    ax.value <- 1;  xx <- x.coords;  yy <- par("usr")[3] - (.15 * usr.y.in)
+  }
+  else {
+    usr.x.in <- diff(grconvertX(0:1, 'inches', 'user'))  # x user x.coords inch
+    ax.value <- 2;  xx <- par("usr")[1] - (.15 * usr.x.in);  yy <- x.coords
+  }
+
+  adj.x <- ifelse(!horiz, 0.5, 1.0)
+  adj.y <- ifelse(!horiz, 1.0, 0.5)
+  if (rotate.x == 0) {
+    axis(ax.value, at=x.coords, labels=FALSE, tck=-.02, col=axis.x.color, ...)
+    text(x=xx, y=yy, labels=val.lab, adj=c(adj.x,adj.y),
+         xpd=TRUE, cex=axis.x.cex, col=axis.x.text.color, ...)
+  }
+  else if (rotate.x > 0  && rotate.x < 90) {
+    axis(ax.value, at=x.coords, labels=FALSE, tck=-.02, col=axis.x.color, ...)
+    text(x=xx, y=yy, labels=val.lab, pos=1,  # pos needed for offset
+         xpd=TRUE, cex=axis.x.cex, col=axis.x.text.color,
+         srt=rotate.x, offset=offset, ...)
+  }
+  else if (rotate.x == 90)  # 90 degrees rotate 
+    axis(ax.value, at=x.coords, labels=val.lab, tck=-.02, col=axis.x.color,
+         cex.axis=axis.x.cex, las=2, ...)
+
   # title
-  title(main=main.lab, cex.main= getOption("main.cex"),
+  title(main=main.lab, cex.main=getOption("main.cex"),
         col.main=getOption("main.color"))
 
-  # xlab positioning
-  lblx.lns <- ifelse (grepl("\n", x.lab, fixed=TRUE), 3.1, 2.2)
-  new.ln <- FALSE
-  if (!is.null(val.lab))
-    for (i in 1:length(val.lab)) 
-      if (grepl("\n", val.lab[i], fixed=TRUE)) new.ln <- TRUE
-  if (new.ln) lblx.lns <- lblx.lns + 1
-  if (offset > 0.5) lblx.lns <- lblx.lns + 1 
-  if (horiz) lblx.lns <- lblx.lns + .6 
   lab.x.color <- ifelse(is.null(getOption("lab.x.color")), 
     getOption("lab.color"), getOption("lab.x.color"))
-  title(xlab=x.lab, line=lblx.lns, cex.lab=lab.x.cex, col.lab=lab.x.color)
+
+  # xlab positioning
+  ln.ht.x <- par('cin')[2] * lab.x.cex * par('lheight')  # line ht inches
+  xlab.adj <- xlab.adj / ln.ht.x
+  lblx.lns <- par("mar")[1] - 1.3   # par("mar")[1] is bm in lines
+  title(xlab=x.lab, line=lblx.lns-xlab.adj, cex.lab=lab.x.cex,
+        col.lab=lab.x.color)
 
   # ylab positioning (based on .axlabs function)
-  lbl.lns <- 3.6
-  multi <- FALSE
-  for (i in 1:length(y.lab))
-    if (!is.null(y.lab))
-      if (grepl("\n", y.lab[i], fixed=TRUE)) multi <- TRUE  # multi-line
-  lm <- par("mar")[2]  # get the current left margin
-  lbly.lns <- ifelse (multi, lm - 2.3, lm - 1.4)
   lab.y.color <- ifelse(is.null(getOption("lab.y.color")), 
-    getOption("lab.color"), getOption("lab.y.color"))
-  title(ylab=y.lab, line=lbly.lns, cex.lab=lab.y.cex, col.lab=lab.y.color)
+  getOption("lab.color"), getOption("lab.y.color"))
+  ln.ht.y <- par('cin')[2] * lab.y.cex * par('lheight')  # line ht inches
+  ylab.adj <- ylab.adj / ln.ht.y
+  lm <- par("mar")[2]  # get current left margin in lines
+  lbly.lns <- lm - (0.3 + 0.9*n.lab.y.ln)
+  title(ylab=y.lab, line=lbly.lns-ylab.adj,
+        cex.lab=lab.y.cex, col.lab=lab.y.color)
 
-  # ----------------------------------------------------------------------------
+
+  # ------------------------------------------------------
   # legend for two variable plot including variable labels
+
   if ( (!is.null(by) || is.matrix(x)) && !is.null(legend.loc))  {
 
     col.txt <- ifelse (sum(col2rgb(col.bg))/3 > 80, "black", rgb(.97,.97,.97))
@@ -529,10 +640,11 @@ function(x, y, by,
   dd <- .getdigits(x, min.digits=0) - 1
   n.dim <- length(dim(x))
   stats <- ""
-  # one variable, dim == 0 if x<-x.temp 
+
+  # x is a table, could be real values or integers <0 if y is specified
+  # no by variable, dim == 0 if x<-x.temp 
   if (n.dim == 1) {
-    # only process if counts
-    if (.is.integer(x)  &&  all(x >= 0)  &&  is.null(y) ) {
+    if (.is.integer(x)  &&  all(x >= 0)) {  # x is table of count-like values
 
       txsug <- ""
       if (getOption("suggest")) {
@@ -546,51 +658,60 @@ function(x, y, by,
                     ", horiz=TRUE)  # horizontal bar chart", sep="")
         txsug <- paste(txsug, "\n", fc, sep="")
         fc <- paste("BarChart(", x.name,
-                    ", fill=\"hcl\")  # hcl colorspace bar colors", sep="")
+                 ", fill=\"colors\", color=\"off\")  # hcl bar colors", sep="")
         txsug <- paste(txsug, "\n", fc, sep="")
         fc <- paste("PieChart(", x.name, ")  # doughnut chart", sep="")
         txsug <- paste(txsug, "\n", fc, sep="")
       }
 
-      if (is.null(y)) {
+      stats <- .ss.factor(x, by=NULL, brief=TRUE, digits.d=NULL,
+                          x.name, by.name, x.lbl, y.lbl, label.max,
+                          x.miss, by.miss, out.size)
 
-        stats <- .ss.factor(x, by=NULL, brief=TRUE, digits.d=NULL,
-                            x.name, by.name, x.lbl, y.lbl, label.max)
+      if (!is.null(stats)) {
+        txttl <- stats$title
+        counts <- stats$count
+        miss <- stats$miss
+        chi <- stats$chi
+        lbl <- stats$lbl
 
-        if (!is.null(stats)) {
-          txttl <- stats$title
-          counts <- stats$count
-          chi <- stats$chi
+        class(txsug) <- "out_piece"
+        class(txttl) <- "out_piece"
+        class(counts) <- "out_piece"
+        class(miss) <- "out_piece"
+        class(chi) <- "out_piece"
+        class(lbl) <- "out_piece"
+        output <- list(out_suggest=txsug, out_title=txttl, out_miss=miss,
+                       out_lbl=lbl, out_counts=counts, out_chi=chi)
+        class(output) <- "out_all"
+        if (!quiet) print(output)      
+      }
+    }  # end counts or count-like
 
-          class(txsug) <- "out_piece"
-          class(txttl) <- "out_piece"
-          class(counts) <- "out_piece"
-          class(chi) <- "out_piece"
-          output <- list(out_suggest=txsug, out_title=txttl, out_counts=counts,
-                         out_chi=chi)
-          class(output) <- "out_all"
-          if (!quiet) print(output)      
-        }
-      }  # is.null(y)
-    }
-    else 
-      stats <- NULL
+    else {  # x (table from y) not count-like: not integer or values < 0
 
-    if (!is.null(y) || !.is.integer(x)) {
-      stats <- .ss.real(x, y, by, digits.d=dd,
+      txsug <- ""
+      if (getOption("suggest")) {
+        y.name <- getOption("yname")
+        txsug <- ">>> Suggestions"
+        fc <- paste("Plot(", y.name, ", ", x.name, ") # lollipop plot", sep="")
+        txsug <- paste(txsug, "\n", fc, sep="")
+      }
+
+      stats <- .ss.real(x, by, digits.d=dd,
                    x.name, getOption("yname"), by.name, x.lbl, y.lbl, label.max) 
       txtbl <- stats$txtbl 
+      class(txsug) <- "out_piece"
       class(txtbl) <- "out_piece"
-      output <- list(out_txt=txtbl)
+      output <- list(out_suggest=txsug, out_txt=txtbl)
 
       class(output) <- "out_all"
       if (!quiet) print(output)         
     }
   }  # if (n.dim == 1)
 
-  # two variables
+  # a by variable
   else {
-    # need brief=FALSE for row proportions
 
     txsug <- ""
     if (getOption("suggest")) {
@@ -601,25 +722,28 @@ function(x, y, by,
                   ", horiz=TRUE)  # horizontal bar chart", sep="")
       txsug <- paste(txsug, "\n", fc, sep="")
       fc <- paste("BarChart(", x.name,
-                  ", fill=\"hcl\")  # different bar colors", sep="")
+                  ", fill=\"colors\")  # different bar colors", sep="")
       txsug <- paste(txsug, "\n", fc, sep="")
     }
 
     if (is.null(y) && .is.integer(x)) {
 
+      # need brief=FALSE for row proportions
       stats <- .ss.factor(x, by, brief=FALSE, digits.d=NULL,
                         x.name, by.name, x.lbl, y.lbl, label.max) 
       txttl <- stats$txttl
       txfrq <- stats$txfrq
       txXV <- stats$txXV
+      txlbl <- stats$txlbl
 
       class(txsug) <- "out_piece"
       class(txttl) <- "out_piece"
       class(txfrq) <- "out_piece"
       class(txXV) <- "out_piece"
+      class(txlbl) <- "out_piece"
       if (!prop)
-        output <- list(out_suggest=txsug, out_title=txttl, out_text=txfrq,
-                       out_XV=txXV)
+        output <- list(out_suggest=txsug, out_title=txttl, out_lbl=txlbl,
+                       out_text=txfrq, out_XV=txXV)
       else {
         txrow <- stats$txrow
         class(txrow) <- "out_piece"
@@ -630,8 +754,8 @@ function(x, y, by,
     }  # end is.null(y)
 
     else {  # y is present
-      stats <- .ss.real(x, y, by, digits.d=3,
-                        x.name, getOption("yname"), by.name, x.lbl, y.lbl, label.max) 
+      stats <- .ss.real(x, y, by, digits.d=3, x.name,
+                        getOption("yname"), by.name, x.lbl, y.lbl, label.max) 
       txtbl <- stats$txtbl 
       class(txtbl) <- "out_piece"
       output <- list(out_txt=txtbl)
@@ -659,3 +783,4 @@ function(x, y, by,
   return(stats)
 
 }
+
