@@ -39,21 +39,21 @@ function(lm.out, cook, cooks.cut,
   fit.ord <- fit[ord]
   res.ord <- res[ord]
 
-  par(bg=getOption("device.fill"))
+  par(bg=getOption("window.fill"))
 
   plot(fit.ord, res.ord, type="n", axes=FALSE, ann=FALSE)
 
   usr <- par("usr")
   rect(usr[1], usr[3], usr[2], usr[4],
-       col=getOption("bg.fill"), border=getOption("bg.stroke"))
+       col=getOption("panel.fill"), border=getOption("panel.color"))
 
-  abline(v=axTicks(1), col=getOption("grid.x.stroke"),
+  abline(v=axTicks(1), col=getOption("grid.x.color"),
          lwd=getOption("grid.lwd"), lty=getOption("grid.lty"))
-  abline(h=axTicks(2), col=getOption("grid.y.stroke"),
+  abline(h=axTicks(2), col=getOption("grid.y.color"),
          lwd=getOption("grid.lwd"), lty=getOption("grid.lty"))
 
   .axes(NULL, NULL, axTicks(1), axTicks(2),
-        par("usr")[1], par("usr")[3], cex.axis=.8, col.axis="gray30")
+        par("usr")[1], par("usr")[3])
 
   main.lab <- NULL
   sub.lab <- "Largest Cook's Distance Highlighted"
@@ -62,15 +62,15 @@ function(lm.out, cook, cooks.cut,
   .axlabs(x.label, y.label, main.lab, sub.lab, max.lbl.y=3, cex.lab=0.85) 
 
   col.fill <- getOption("pt.fill")
-  col.stroke <- getOption("pt.stroke")
-  points(fit.ord, res.ord, pch=21, col=col.stroke, bg=col.fill, cex=0.8)
+  col.color <- getOption("pt.color")
+  points(fit.ord, res.ord, pch=21, col=col.color, bg=col.fill, cex=0.8)
 
   abline(h=0, lty="dotted", lwd=1.5, col=getOption("bar.fill"))
-  lines(lowess(fit.ord, res.ord, f=.9), col=getOption("pt.stroke"))
+  lines(lowess(fit.ord, res.ord, f=.9), col=getOption("pt.color"))
   res.c <- res[which(cook>=cooks.cut)]
   fit.c <- fit[which(cook>=cooks.cut)]
   if (length(fit.c) > 0) {
-    col.out <- getOption("pt.stroke")
+    col.out <- getOption("pt.color")
     points(fit.c, res.c, col=col.out, pch=19)
     text(fit.c, res.c, names(fit.c), pos=1, cex=.8)
   }
